@@ -1,7 +1,7 @@
-from viso_sdk.visualize.viz_text import VizTextDraw
 from viso_sdk.visualize.viz_roi import VizPolygonDraw
 from viso_sdk.visualize.viz_object import VizObjectDraw
 from viso_sdk.visualize.palette import get_rgba_color_with_palette_id
+from viso_sdk.visualize import utils
 
 
 class BaseVisualization:
@@ -10,26 +10,23 @@ class BaseVisualization:
                  object_vis_params,
                  roi_vis_params
                  ):
-        self.text_drawer = VizTextDraw(
-            font_size=text_vis_params.get('text_size', None),
-            font_color=text_vis_params.get('text_color', None)
-        )
+        self.default_font = utils.init_font(font_size=text_vis_params.get('text_size', utils.DEFAULT_FONT_SIZE))
 
         self.object_drawer = VizObjectDraw(
-            bbox_color=object_vis_params.get('bbox_color', None),
-            bbox_thickness=object_vis_params.get('bbox_thickness', None),
-            text_size=object_vis_params.get('text_size', None),
-            text_color=object_vis_params.get('text_color', None)
+            bbox_color=object_vis_params.get('bbox_color', utils.DEFAULT_ROI_OUTLINE_COLOR),
+            bbox_thickness=object_vis_params.get('bbox_thickness', utils.DEFAULT_ROI_OUTLINE_THICKNESS),
+            text_size=object_vis_params.get('text_size', utils.DEFAULT_FONT_SIZE),
+            text_color=object_vis_params.get('text_color', utils.DEFAULT_TXT_COLOR)
         )
 
         self.roi_drawer = VizPolygonDraw(
             show_roi=roi_vis_params.get('show_roi', None),
-            roi_color=roi_vis_params.get('roi_color', None),
-            outline_color=roi_vis_params.get('outline_color', None),
-            outline_thickness=roi_vis_params.get('outline_thickness', None),
+            roi_color=roi_vis_params.get('roi_color', utils.DEFAULT_ROI_COLOR),
+            outline_color=roi_vis_params.get('outline_color', utils.DEFAULT_ROI_OUTLINE_COLOR),
+            outline_thickness=roi_vis_params.get('outline_thickness', utils.DEFAULT_ROI_OUTLINE_THICKNESS),
             show_label=roi_vis_params.get('show_label', True),
-            label_size=roi_vis_params.get('label_size', None),
-            label_color=roi_vis_params.get('label_color', None)
+            label_size=roi_vis_params.get('label_size', utils.DEFAULT_LABEL_SIZE),
+            label_color=roi_vis_params.get('label_color', utils.DEFAULT_LABEL_COLOR)
         )
 
     @staticmethod
