@@ -5,18 +5,15 @@ from PIL import ImageDraw, Image
 from viso_sdk.constants import KEY
 
 from viso_sdk.visualize.palette import get_rgba_color_with_palette_id, get_rgba_color
-from viso_sdk.visualize.viz_text import VizTextDraw
+from viso_sdk.visualize import utils
 
 
 class VizObjectDraw:
-    def __init__(self, bbox_color, bbox_thickness, text_color, text_size):
+    def __init__(self, bbox_color, bbox_thickness, text_size):
         self.bbox_color = get_rgba_color(bbox_color)
         self.bbox_thickness = bbox_thickness
 
-        self.label_drawer = VizTextDraw(
-            font_color=text_color,
-            font_size=text_size
-        )
+        self.default_font = utils.init_font(font_size=text_size)
 
     def _draw_objs_(
             self,
@@ -56,9 +53,13 @@ class VizObjectDraw:
 
                 # get text label
                 if show_label:
-                    draw = self.label_drawer.draw_texts(
-                        draw=draw, pos=(x, y), text=label,
-                        fill_rectangle=True, fill_rectangle_color=bbox_color,
+                    utils.put_text(
+                        font=self.default_font,
+                        draw=draw,
+                        bbox=(x, y),
+                        text=label,
+                        bbox_thickness=-1,
+                        bbox_color=bbox_color,
                         # show_shadow=True
                     )
 
