@@ -2,48 +2,37 @@ import numpy as np
 import cv2
 from PIL import ImageDraw, Image
 
-from viso_sdk.visualize.viz_text import VizTextDraw
 from viso_sdk.visualize.palette import get_rgba_color
+from viso_sdk.visualize import utils
 
 # from viso_sdk.logging import get_logger
 # logger = get_logger("vis-roi")
 
 
-DEFAULT_ROI_COLOR = (255, 150, 113, 0.4)
-DEFAULT_ROI_OUTLINE_COLOR = (70, 70, 70, 1.0)
-DEFAULT_ROI_OUTLINE_THICKNESS = 1
-DEFAULT_LABEL_COLOR = (255, 255, 255, 0.4)
-DEFAULT_LABEL_SIZE = 20
-
-
 class VizPolygonDraw:
     def __init__(self,
                  show_roi=True,
-                 roi_color=DEFAULT_ROI_COLOR,
-                 outline_color=DEFAULT_ROI_COLOR,
-                 outline_thickness=DEFAULT_ROI_OUTLINE_THICKNESS,
+                 roi_color=utils.DEFAULT_ROI_COLOR,
+                 outline_color=utils.DEFAULT_ROI_COLOR,
+                 outline_thickness=utils.DEFAULT_ROI_OUTLINE_THICKNESS,
                  show_label=False,
-                 label_size=DEFAULT_LABEL_COLOR,
-                 label_color=DEFAULT_LABEL_SIZE
+                 label_size=utils.DEFAULT_LABEL_SIZE,
                  ):
 
         self.show_roi = show_roi
         self.show_label = show_label
 
-        self.label_drawer = VizTextDraw(
-            font_size=label_size,
-            font_color=get_rgba_color(label_color)
-        )
+        self.default_font = utils.init_font(font_size=label_size)
 
         if roi_color is None:
-            roi_color = DEFAULT_ROI_COLOR
+            roi_color = utils.DEFAULT_ROI_COLOR
         self.default_roi_color = get_rgba_color(roi_color)
 
         if outline_color is None:
             if roi_color is not None:
                 outline_color = [roi_color[0] + 10, roi_color[1] + 10, roi_color[2] + 10, roi_color[3]]
             else:
-                outline_color = DEFAULT_ROI_OUTLINE_COLOR
+                outline_color = utils.DEFAULT_ROI_OUTLINE_COLOR
         self.default_outline_color = get_rgba_color(outline_color)
 
         # if outline_thickness is None:
@@ -118,12 +107,15 @@ class VizPolygonDraw:
             )
 
             if self.show_label:
-                self.label_drawer.draw_texts(
-                    draw=draw, pos=(int(x0), int(y0)),
+                utils.put_text(
+                    draw=draw,
+                    font=self.default_font,
+                    bbox=(x0, y0),
                     large_padding=True,
                     text=label,
                     show_shadow=True,
-                    fill_rectangle=False
+                    bbox_thickness=None,
+                    bbox_color=None
                 )
 
         pil_out = Image.alpha_composite(pil_base_im, pil_viz_im)
